/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.dao;

/**
 * This software is the property of Portland Webworks.
 *
 * Assign this annotation to an enumerated value that is to be used as a eager fetch indicator, where the name of the
 * enumerated value does not map exactly to the name of the eagerly fetched field.  For example, if you have this
 * relationship:
 *
 * cat --> kitten --> mouse
 *
 * and you want to ensure that when you load a cat, you are also eagerly loading all cat's kitten's mice, you might
 * have these enumerated fetch options:
 *
 * enum CatFetchOptions {
 *   kittens,
 *   @FetchOption("kittens.mice")
 *   eachKittensMice
 *  }
 *
 * @Author rnorthup
 */
@java.lang.annotation.Retention(java.lang.annotation.RetentionPolicy.RUNTIME)
@java.lang.annotation.Target({java.lang.annotation.ElementType.ANNOTATION_TYPE})
public @interface FetchOption
{
	String value();
}