/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.dao;

import com.portlandwebworks.commons.domain.ViewBase;

import java.util.Collection;

/**
 * This software is the property of Portland Webworks.
 *
 * This is an abbreviated version of IDaoBase for read-only data where an entity is mapped to a view.  There are
 * obviously no write operations.
 *
 * @Author rnorthup
 */
public interface IViewDaoBase<T extends ViewBase>
{
	/**
	 * Generic method to return a collection of view results that match the criteria provided.
	 * @param criteria
	 * @return
	 */
	public Collection<T> findAllByCriteria(SearchCriteria criteria);

	/**
	 * Generic method to return a "page" of search results suitable for display in a grid view.
	 *
	 * @param criteria
	 * @param options
	 * @return
	 */
	public GridDisplayResults<T> search(SearchCriteria criteria, GridDisplayOptions options);
}
