/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.dao;

import java.util.Collection;
import java.util.Date;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class Predicate
{
	private String joinPath;
	private String property;
	private Operator operator;
	private Object value;

	public static Predicate equalTo(String property, Object value)
	{
		return new Predicate(property, Operator.EqualTo, value);
	}

	public static Predicate notEqualTo(String property, Object value)
	{
		return new Predicate(property, Operator.NotEqualTo, value);
	}

	public static Predicate isNull(String property)
	{
		return new Predicate(property, Operator.IsNull, null);
	}

	public static Predicate isNotNull(String property)
	{
		return new Predicate(property, Operator.IsNotNull, null);
	}

	public static Predicate matches(String property, String value)
	{
		return new Predicate(property, Operator.Matches, value);
	}

	public static Predicate startsWith(String property, String value)
	{
		return new Predicate(property, Operator.StartsWith, value);
	}

	public static Predicate endsWith(String property, String value)
	{
		return new Predicate(property, Operator.EndsWith, value);
	}

	public static Predicate greaterThan(String property, Number value)
	{
		return new Predicate(property, Operator.GreaterThan, value);
	}

	public static Predicate greaterThan(String property, Date value)
	{
		return new Predicate(property, Operator.GreaterThan, value);
	}

	public static Predicate lessThan(String property, Number value)
	{
		return new Predicate(property, Operator.LessThan, value);
	}

	public static Predicate lessThan(String property, Date value)
	{
		return new Predicate(property, Operator.LessThan, value);
	}

	public static Predicate greaterThanOrEqual(String property, Number value)
	{
		return new Predicate(property, Operator.GreaterThanOrEqual, value);
	}

	public static Predicate greaterThanOrEqual(String property, Date value)
	{
		return new Predicate(property, Operator.GreaterThanOrEqual, value);
	}

	public static Predicate lessThanOrEqual(String property, Object value)
	{
		return new Predicate(property, Operator.LessThanOrEqual, value);
	}

	public static Predicate lessThanOrEqual(String property, Number value)
	{
		return new Predicate(property, Operator.LessThanOrEqual, value);
	}

	public static Predicate lessThanOrEqual(String property, Date value)
	{
		return new Predicate(property, Operator.LessThanOrEqual, value);
	}

	public static Predicate isIn(String property, Object[] value)
	{
		return new Predicate(property, Operator.IsIn, value);
	}

	public static Predicate isIn(String property, Collection value)
	{
		return new Predicate(property, Operator.IsIn, value);
	}

	public static Predicate countEqualTo(String property, int count)
	{
		return new Predicate(property, Operator.CountEqualTo, count);
	}

	public static Predicate countNotEqualTo(String property, int count)
	{
		return new Predicate(property, Operator.CountNotEqualTo, count);
	}

	public static Predicate countGreaterThan(String property, int count)
	{
		return new Predicate(property, Operator.CountGreaterThan, count);
	}

	public static Predicate countGreaterThanOrEqual(String property, int count)
	{
		return new Predicate(property, Operator.CountGreaterThan, count);
	}

	public static Predicate countLessThan(String property, int count)
	{
		return new Predicate(property, Operator.CountLessThan, count);
	}

	public static Predicate CountLessThanOrEqual(String property, int count)
	{
		return new Predicate(property, Operator.CountLessThanOrEqual, count);
	}

	public Predicate()
	{
	}

	public Predicate(String joinPath, String property, Operator operator, Object value)
	{
		this.joinPath = joinPath;
		this.property = property;
		this.operator = operator;
		this.value = value;
	}

	public Predicate(String property, Operator operator, Object value)
	{
		this.property = property;
		this.operator = operator;
		this.value = value;
	}

	public String getProperty()
	{
		return property;
	}

	public void setProperty(String property)
	{
		this.property = property;
	}

	public Operator getOperator()
	{
		return operator;
	}

	public void setOperator(Operator operator)
	{
		this.operator = operator;
	}

	public Object getValue()
	{
		return value;
	}

	public void setValue(Object value)
	{
		this.value = value;
	}

	public String getJoinPath()
	{
		return joinPath;
	}

	public void setJoinPath(String joinPath)
	{
		this.joinPath = joinPath;
	}
}
