/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.data;

import org.apache.commons.beanutils.PropertyUtils;

import java.lang.reflect.InvocationTargetException;
import java.util.ArrayList;
import java.util.Collection;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class LabelValuePair<V>
{
	private String label;

	private V value;

	public LabelValuePair()
	{
	}

	public LabelValuePair(String label, V value)
	{
		this.label = label;
		this.value = value;
	}

	public String getLabel()
	{
		return label;
	}

	public void setLabel(String label)
	{
		this.label = label;
	}

	public V getValue()
	{
		return value;
	}

	public void setValue(V value)
	{
		this.value = value;
	}

	public static <T> LabelValuePair withValue(T value)
	{
		return new LabelValuePair<T>(null, value);
	}

	public static <T> Collection<LabelValuePair<T>> withValues(Collection<T> values)
	{
		ArrayList<LabelValuePair<T>> lvps = new ArrayList<LabelValuePair<T>>(values.size());

		for (T value : values) {
			lvps.add(new LabelValuePair<T>(null, value));
		}

		return lvps;
	}

	public static <T> Collection<T> getValues(Class<T> type, Collection<LabelValuePair<T>> pairs)
	{
		ArrayList<T> array = new ArrayList<T>(pairs.size());

		for (LabelValuePair<T> pair : pairs) {
			array.add(pair.getValue());
		}
		return array;
	}

	public static <T> Collection<LabelValuePair<T>> fromBeans(Collection beans, String labelProperty, String valueProperty)
	{
		ArrayList<LabelValuePair<T>> lvps = new ArrayList<LabelValuePair<T>>(beans.size());

		try {
			for (Object bean : beans) {
				LabelValuePair<T> lvp = new LabelValuePair<T>();
				Object label = PropertyUtils.getProperty(bean, labelProperty);
				if (label == null)
					label = "";
				lvp.setLabel(label.toString());
				lvp.setValue((T)PropertyUtils.getProperty(bean, valueProperty));
				lvps.add(lvp);
			}
		}
		catch (InvocationTargetException e) {
			throw new RuntimeException("Exception occured invoking bean property getter: " + e.getCause().getMessage(), e.getCause());
		}
		catch (IllegalAccessException e) {
			throw new RuntimeException("Inaccessible property specified for bean");
		}
		catch (NoSuchMethodException e) {
			throw new RuntimeException("Invalid property specified for bean");
		}

		return lvps;
	}

}