/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.domain;

import javax.persistence.*;

/**
 * This software is the property of Portland Webworks.
 *
 * This entity base class provides common behavior for an entity's primary key.
 *
 * An entity is equal to another if both identifiers are non-null and are the same value.
 * The entity's identifier is used to generate its hashcode value.
 *
 * This base class is also annotated to be a superclass for JPA entities.  The identifier generator
 * type is GenerationType.AUTO to allow it to be used with any database.  However, if it is used on
 * a database that requires additional generation info (for example, an Oracle or Postgre sequence),
 * you will need to utilize a custom dialect, for example the CustomOracle9iDialect, that provides
 * a custom sequence generator that defaults the sequence name based on the entity's table name.
 *
 * @see com.portlandwebworks.commons.hibernate.CustomOracle9iDialect
 * @see com.portlandwebworks.commons.hibernate.TableNameSequenceGenerator
 *
 * @Author rnorthup
 */
@MappedSuperclass
public class EntityBase extends IEntity<Long>
{
	/**
	 * Specifying AUTO allows this entity base class to work with any database that provides a way to auto-generate
	 * unique IDs.
	 */
	@Id
	@GeneratedValue(strategy = GenerationType.AUTO)
	@Column(name = "id", precision = 19, scale = 0)
	private Long id;

	@Override
	public Long getId()
	{
		return id;
	}

	@Override
	public void setId(Long id)
	{
		this.id = id;
	}
}