/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.email.template;

import org.apache.log4j.Logger;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.HashMap;
import java.util.List;
import java.util.Locale;
import java.util.Map;

/**
 * This software is the property of Portland Webworks.
 *
 * This email template provider leverages dependency injection to obtain its list of <code>SimpleEmailTemplate</code>
 * instances, making it suitable for deployment into a spring framework container.
 *
 * @Author rnorthup
 */
public class SimpleBeanBasedTemplateProvider implements IEmailTemplateProvider
{
	private static Logger logger = Logger.getLogger(SimpleBeanBasedTemplateProvider.class);


	private Map<String, SimpleEmailTemplate> templateLookup;

	/**
	 * Populates this provider with a list of templates that will be available to the application.
	 *
	 * @param templates
	 */
	@Autowired(required = true)
	public void setTemplates(List<SimpleEmailTemplate> templates)
	{
		templateLookup = new HashMap<String, SimpleEmailTemplate>();

		for (SimpleEmailTemplate template : templates) {
			
			logger.debug("Loading email template: " + template.getName());

			templateLookup.put(template.getName(), template);
		}
	}

	public IEmailTemplate getTemplate(String templateName)
	{
		SimpleEmailTemplate template = templateLookup.get(templateName);
		if (template == null) {
			throw new RuntimeException("No template found named " + templateName);
		}
		return template;
	}

	public IEmailTemplate getTemplate(String templateName, Locale locale)
	{
		SimpleEmailTemplate template = templateLookup.get(templateName + "." + locale.getDisplayName());
		if (template == null) {
			template = templateLookup.get(templateName);
		}
		if (template == null) {
			throw new RuntimeException("No template found named " + templateName);
		}
		return template;
	}
}
