/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.email.template;

import org.apache.velocity.Template;
import org.apache.velocity.app.VelocityEngine;

import java.io.File;
import java.io.InputStream;
import java.util.Locale;
import java.util.Map;
import java.util.Properties;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class VelocityTemplateProvider implements IEmailTemplateProvider
{
	protected VelocityEngine velocityEngine;

	protected String templateDirectory;

	public String getTemplateDirectory()
	{
		return templateDirectory;
	}

	public void setTemplateDirectory(String templateDirectory)
	{
		this.templateDirectory = templateDirectory;
	}

	public void initialize()
	{
		velocityEngine = new VelocityEngine();
		velocityEngine.setProperty(VelocityEngine.RUNTIME_LOG_LOGSYSTEM_CLASS, this.getClass());

		Properties props = new Properties();
		props.setProperty("resource.loader", "class");
		props.setProperty("class.resource.loader.class", "org.apache.velocity.runtime.resource.loader.ClasspathResourceLoader");
		//props.setProperty("class.resource.loader.path", templateDirectory);
		props.setProperty("class.resource.cache", "false");
		props.setProperty("class.resource.loader.modificationCheckInterval", "120");
/*
		props.setProperty("file.resource.loader.class", "org.apache.velocity.runtime.resource.loader.FileResourceLoader");
		props.setProperty("file.resource.loader.path", templateDirectory);
		props.setProperty("file.resource.cache", "false");
		props.setProperty("file.resource.loader.modificationCheckInterval", "120");
*/

		try {
			velocityEngine.init(props);
		}
		catch (Exception e) {
			throw new RuntimeException("Unhandled exception initializing velocity engine", e);
		}

	}

	public IEmailTemplate getTemplate(String templateName)
	{
		return getTemplate(templateName, Locale.getDefault());
	}

	public IEmailTemplate getTemplate(String templateName, Locale locale)
	{
/*
		File templateFile = new File(new File(templateDirectory, locale.getLanguage() + "_" + locale.getCountry()), templateName + ".vm");
		if (! templateFile.exists()) {
			templateFile = new File(new File(templateDirectory, locale.getLanguage()), templateName + ".vm");
			if (! templateFile.exists()) {
				templateFile = new File(templateDirectory, templateName + ".vm");
				if (! templateFile.exists()) {
				}
			}
		}
*/

		String resourcePath = templateDirectory + "/" + locale.getLanguage() + "_" +
				locale.getCountry() + "/" + templateName + ".vm";

		InputStream in = this.getClass().getResourceAsStream(resourcePath);
		if (in == null) {

			resourcePath = templateDirectory + "/" + locale.getLanguage() + "/" + templateName + ".vm";
			in = this.getClass().getResourceAsStream(resourcePath);
			if (in == null) {

				resourcePath = templateDirectory + "/" + templateName + ".vm";
				in = this.getClass().getResourceAsStream(resourcePath);
				if (in == null) {
					throw new RuntimeException("Could not find template " + templateName + " for any locale");
				}
			}
		}

		try {
			Template vm = velocityEngine.getTemplate(resourcePath);
			return new VelocityEmailTemplate(vm);
		}
		catch (Exception e) {
			throw new RuntimeException("Unhandled exception loading velocity template " + resourcePath, e);
		}
	}
}
