/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.hibernate;

import com.portlandwebworks.commons.dao.ILookupValueDaoBase;
import com.portlandwebworks.commons.domain.LookupValueBase;
import org.hibernate.Criteria;
import org.hibernate.criterion.Order;
import org.hibernate.criterion.Restrictions;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * This software is the property of Portland Webworks.
 *
 * Subclass of LookupValueBase that provides some convenience functionality for
 *
 * @Author rnorthup
 */
public class LookupValueHibernateDaoBase extends HibernateDaoBase implements ILookupValueDaoBase
{
	public <T extends LookupValueBase> List<T> findAllEnabled(Class<T> lookupClass)
	{
		Criteria query = getSession().createCriteria(lookupClass);

		query.add(Restrictions.eq("enabled", true));

		query.add(Restrictions.eq("customEntry", false));

		query.addOrder(Order.asc("displayOrder"));

		return query.list();
	}

	public <T extends LookupValueBase> Map<Integer, T> mapAllEnabled(Class<T> lookupClass)
	{
		Criteria query = getSession().createCriteria(lookupClass);

		query.add(Restrictions.eq("enabled", true));

		query.add(Restrictions.eq("customEntry", false));

		List<T> results = query.list();

		Map<Integer, T> map = new HashMap<Integer,T>();

		for (T result : results) {
			map.put(result.getId(), result);
		}

		return map;
	}

	public <T extends LookupValueBase> List<T> findAllEnabledIncluding(Class<T> lookupClass, Integer[] customValueIds)
	{
		Criteria query = getSession().createCriteria(lookupClass);

		query.add(Restrictions.eq("enabled", true));

		query.add(Restrictions.or(
				Restrictions.eq("customEntry", false),
				Restrictions.in("id", customValueIds)
		));

		query.addOrder(Order.asc("displayOrder"));

		return query.list();
	}

	public <T extends LookupValueBase> List<T> findAllEnabledAssignedToParent(Class<T> lookupClass, int parentId)
	{
		Criteria query = getSession().createCriteria(lookupClass);

		query.add(Restrictions.eq("enabled", true));

		query.addOrder(Order.asc("displayOrder"));

		return query.list();
	}
}