/*
 * Copyright 2010 Portland Webworks, Inc.
 *
 * This file is part of PWW Commons.
 *
 * PWW Commons is free software: you can redistribute it and/or modify it under the terms of the GNU Lesser General
 * Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any
 * later version.
 *
 * PWW Commons is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for
 * more details.
 *
 * You should have received a copy of the GNU Lesser General Public License along with PWW Commons.  If not, see
 * <http://www.gnu.org/licenses/>.
 */

package com.portlandwebworks.commons.security;

import junit.framework.Assert;
import org.apache.log4j.Logger;
import org.springframework.context.ApplicationContext;
import org.springframework.test.context.TestContext;
import org.springframework.test.context.TestExecutionListener;

/**
 * This software is the property of Portland Webworks.
 *
 * @Author rnorthup
 */
public class AuthenticationTestExecutionListener implements TestExecutionListener
{
	private static Logger logger = Logger.getLogger(AuthenticationTestExecutionListener.class);


	private void doAuthentication(ApplicationContext context, String login, String password)
	{
		ISecurityProvider securityProvider = context.getBean(ISecurityProvider.class);
		if (securityProvider == null) {
			throw new RuntimeException("Could not find an ISecurityProvider bean in your spring context.");
		}

		// Manually authenticate with a test user.
		AuthenticationResult result = securityProvider.authenticate(login, password);

		Assert.assertTrue("Authentication failed for user " + login, result.isAuthenticated());

		if (result.isAuthenticated()) {
			logger.info("Running as user " + result.getPrincipal());
		}
		else {
			logger.error("Authentication for user " + login + " failed: " + result.getFailureReason());
		}
	}

	public void beforeTestClass(TestContext testContext) throws Exception
	{
		Authentication annot = testContext.getTestClass().getAnnotation(Authentication.class);
		if (annot != null) {
			doAuthentication(testContext.getApplicationContext(), annot.login(), annot.password());
		}
	}

	public void prepareTestInstance(TestContext testContext) throws Exception
	{
	}

	public void beforeTestMethod(TestContext testContext) throws Exception
	{
		Authentication annot = testContext.getTestMethod().getAnnotation(Authentication.class);
		if (annot != null) {
			doAuthentication(testContext.getApplicationContext(), annot.login(), annot.password());
		}
	}

	public void afterTestMethod(TestContext testContext) throws Exception
	{
	}

	public void afterTestClass(TestContext testContext) throws Exception
	{
	}
}
